@@ -9,7 +9,7 @@
 package Video::DVDRip;
 use Locale::TextDomain qw (video.dvdrip);
 
-$VERSION = "0.52.7";
+$VERSION = "0.97.1";
 
 use base Video::DVDRip::Base;
 
@@ -23,7 +23,7 @@ require 5.006;
 	'vcd'       => "MPEG",
 );
 
-%Video::DVDRip::deinterlace_filters = (
+@Video::DVDRip::deinterlace_filters = (
 	0          => __"No deinterlacing",
 	1          => __"Interpolate scanlines (fast)",
 	2          => __"Handled by encoder (may segfault)",
@@ -47,9 +47,6 @@ require 5.006;
 	'normalize' => __"Normalizing (mplayer filter)",
 );
 
-$Video::DVDRIP::scratch_width   = 1024;
-$Video::DVDRIP::scratch_height  = 768;
-
 1;
 
 __END__
