@@ -1,51 +1,52 @@
-# $Id: Pipe.pm,v 1.8.2.2 2003/02/17 21:10:05 joern Exp $
-
-#-----------------------------------------------------------------------
-# Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
-# All Rights Reserved. See file COPYRIGHT for details.
-# 
-# This module is part of Video::DVDRip, which is free software; you can
-# redistribute it and/or modify it under the same terms as Perl itself.
-#-----------------------------------------------------------------------
+# $Id: Pipe.pm,v 1.11 2005/07/23 08:14:15 joern Exp $
 
 package Video::DVDRip::GUI::Pipe;
 
+use Locale::TextDomain qw (video.dvdrip);
+
 use base Video::DVDRip::GUI::Base;
 
 use strict;
+
 use Carp;
-use Data::Dumper;
 use Cwd;
 use FileHandle;
+use Data::Dumper;
 
+use Gtk2::Helper;
 use POSIX qw(:errno_h);
 
 sub fh				{ shift->{fh}				}
 sub command			{ shift->{command}			}
-sub gtk_input			{ shift->{gtk_input}			}
+sub args			{ shift->{args}				}
 sub need_output			{ shift->{need_output}			}
 sub output			{ shift->{output}			}
 sub cb_line_read		{ shift->{cb_line_read}			}
 sub cb_finished			{ shift->{cb_finished}			}
 sub pid				{ shift->{pid}				}
+sub watcher_tag			{ shift->{watcher_tag}			}
 
 sub set_fh			{ shift->{fh}			= $_[1] }
 sub set_command			{ shift->{command}		= $_[1]	}
-sub set_gtk_input		{ shift->{gtk_input}		= $_[1] }
+sub set_args			{ shift->{args}			= $_[1]	}
 sub set_need_output		{ shift->{need_output}		= $_[1]	}
 sub set_output 			{ shift->{output}		= $_[1]	}
 sub set_cb_line_read		{ shift->{cb_line_read}		= $_[1]	}
 sub set_cb_finished		{ shift->{cb_finished}		= $_[1]	}
 sub set_pid			{ shift->{pid}			= $_[1]	}
+sub set_watcher_tag		{ shift->{watcher_tag}		= $_[1]	}
 
 sub new {
 	my $class = shift;
 	my %par = @_;
 	my  ($command, $need_output, $cb_line_read, $cb_finished) =
 	@par{'command','need_output','cb_line_read','cb_finished'};
+	my  ($args) =
+	@par{'args'};
 
 	my $self = {
 		command			=> $command,
+		args			=> ($args || []),
 		need_output		=> $need_output,
 		cb_line_read		=> $cb_line_read,
 		cb_finished		=> $cb_finished,
@@ -58,92 +59,50 @@ sub open {
 	my $self = shift;
 
 	my $fh  = FileHandle->new;
-	my $pid;
 	
 	# we use fork & exec, because we want to have
 	# STDERR on STDOUT in the child.
-	$pid = open($fh, "-|");
+	my $pid = open($fh, "-|");
 	croak "can't fork child process" if not defined $pid;
 
 	$fh->blocking(0);
-		
+
 	if ( not $pid ) {
 		# we are the child. Copy STDERR to STDOUT
 		close STDERR;
 		open (STDERR, ">&STDOUT")
 			or croak "can't dup STDOUT to STDERR";
-		
-		# simply call exec with one argument, this
-		# will execute the command using a shell
-		exec ($self->command)
+		my $command = $self->command;
+		exec ("dr_exec ".$self->command, @{$self->args})
 			or croak "can't exec program: $!";
 	}
 
-	$self->log ("Executing command: ".$self->command. " (PID=$pid)");
+	$self->log ("Executing command: ".$self->command);
 
-	$self->set_pid ( $pid );
 	$self->set_fh ( $fh );
+	$self->set_pid ( $pid );
 	$self->set_output ( "" );
-	
-	Gtk::Gdk->input_remove ( $self->gtk_input )
-		if defined $self->gtk_input;
 
-	$self->set_gtk_input (
-		Gtk::Gdk->input_add (
+	$self->set_watcher_tag (
+		Gtk2::Helper->add_watch (
 			$fh->fileno,
-			'read', sub { $self->progress }
-		)
+			'in', sub { $self->progress; 1; }
+		),
 	);
 
 	1;
 }
 
-sub progress {
-	my $self = shift; $self->trace_in;
-
-	my $fh = $self->fh;
-
-	# read all date from the pipe
-	my ($tmp, $buffer);
-	while ( $fh->read ($tmp, 8192) ) {
-		$buffer .= $tmp;
-	}
-	my $finished = $! != EAGAIN;
-
-	# store output
-	if ( $self->need_output ) {
-		$self->{output} .= $buffer;
-	} else {
-		$self->{output} = substr($self->{output}.$buffer,-16384);
-	}
-
-	# our callbacks
-	my $cb_finished  = $self->cb_finished;
-	my $cb_line_read = $self->cb_line_read;
-
-	# call callback if we got something
-	&$cb_line_read ( $buffer ) if $cb_line_read and $buffer;
-
-	# are we finished?
-	if ( $finished ) {
-		$self->close;
-		&$cb_finished ();
-		return;
-	}
-
-
-	1;
-}
-
 sub close {
-	my $self = shift; $self->trace_in;
+	my $self = shift;
 
-	Gtk::Gdk->input_remove ( $self->gtk_input ) if $self->gtk_input;
+	Gtk2::Helper->remove_watch ( $self->watcher_tag )
+		if $self->watcher_tag;
 
-	close ($self->fh) if $self->fh;
-	waitpid $self->pid, 0;
+	close ($self->fh)
+		if $self->fh;
 
-	$self->set_gtk_input(undef);
+	$self->set_watcher_tag(undef);
 	$self->set_fh ( undef );
 
 	1;
@@ -152,41 +111,65 @@ sub close {
 sub cancel {
 	my $self = shift;
 
-	# $self->pid belong to the sh we started with exec,
-	# but we want to kill it's child
-	my $child_pid = $self->get_child_pid ( pid => $self->pid );
+	my $pid = $self->pid;
 
-	# kill the child
-	$self->log ("Aborting command. Sending signal 1 to PID $child_pid...");
-	kill 1, $child_pid;
+	if ( $pid ) {
+		$self->log ("Aborting command. Sending signal 9 to PID $pid...");
+		kill 9, $pid;
+	}
 
-	# close this pipe
 	$self->close;
 
 	1;
 }
 
-sub cancel_pstree {
+sub progress {
 	my $self = shift;
 
-	# this pid belong to the sh we started with exec
-	my $pid = $self->pid;
-	
-	# but we want to have its child. We use pstree for that.
-	my $pstree = qx[pstree -p $pid];
-	$pstree =~ /\($pid\).*?\((\d+)/;
-	my $child_pid = $1;
+	my $fh = $self->fh;
 
-	# if there was no sh with a further child, we have to kill
-	# our child process directly
-	$child_pid ||= $pid;
+	# read all date from the pipe
+	my ($tmp, $tmp_buffer);
+	while ( $fh->read ($tmp, 8192) ) {
+		$tmp_buffer .= $tmp;
+	}
+	my $finished = $! != EAGAIN;
 
-	# kill the child
-	$self->log ("Aborting command. Sending signal 1 to PID $child_pid...");
-	kill 1, $child_pid;
+	# store output
+	if ( $self->need_output ) {
+		$self->{output} .= $tmp_buffer;
+	} else {
+		$self->{output} = substr($self->{output}.$tmp_buffer,-16384);
+	}
 
-	# close this pipe
-	$self->close;
+	# get job's PID
+	my ($pid) = ( $tmp_buffer =~ /DVDRIP_JOB_PID=(\d+)/ );
+	if ( defined $pid ) {
+		$self->set_pid ( $pid );
+		$self->log ("Job has PID $pid");
+		$tmp_buffer =~ s/DVDRIP_JOB_PID=(\d+)\n//;
+	}
+
+	# prepend data from previous run
+	my $buffer = $self->{buffer}.$tmp_buffer;
+
+	# our callbacks
+	my $cb_finished  = $self->cb_finished;
+	my $cb_line_read = $self->cb_line_read;
+
+	# process by line
+	while ( $buffer =~ s/(.*)\n// ) {
+		&$cb_line_read ( $1 ) if $cb_line_read;
+	}
+
+	# save rest of buffer
+	$self->{buffer} = $buffer;
+
+	# are we finished?
+	if ( $finished ) {
+		&$cb_finished ();
+		return 1;
+	}
 
 	1;
 }
