@@ -1,4 +1,4 @@
-# $Id: TranscodeAudio.pm,v 1.7 2003/01/28 20:19:57 joern Exp $
+# $Id: TranscodeAudio.pm,v 1.8 2004/04/11 23:36:20 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -9,6 +9,7 @@
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::Job::TranscodeAudio;
+use Locale::TextDomain qw (video.dvdrip);
 
 use base Video::DVDRip::Job::TranscodeVideo;
 
@@ -28,12 +29,14 @@ sub type {
 sub info {
 	my $self = shift; $self->trace_in;
 
-	my $info = "Transcoding audio - title #".$self->title->nr;
+	my $info = __("Transcoding audio");
+	$info .= " - ".__x("title #{title}", title => $self->title->nr);
+
 	my $nr      = $self->vob_nr;
 	my $chapter = $self->chapter;
 	
-	$info .= ", track #$nr";
-	$info .= ", chapter #$chapter" if $chapter;
+	$info .= ", ".__x("track #{nr}", nr => $nr);
+	$info .= ", ".__x("chapter #{chapter}", chapter => $chapter) if $chapter;
 	
 	return $info;
 }
