@@ -1,4 +1,4 @@
-# $Id: Project.pm,v 1.44 2004/10/10 12:48:05 joern Exp $
+# $Id: Project.pm,v 1.45 2005/07/23 08:14:15 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -39,7 +39,6 @@ sub dvd_image_dir		{ shift->{dvd_image_dir}		}
 sub convert_message		{ shift->{convert_message}		}
 sub last_selected_nb_page	{ shift->{last_selected_nb_page}	}
 
-sub set_name			{ shift->{name}			= $_[1] }
 sub set_version			{ shift->{version}		= $_[1] }
 sub set_filename		{ shift->{filename}		= $_[1] }
 sub set_dvd_device		{ shift->{dvd_device}		= $_[1]	}
@@ -65,29 +64,49 @@ sub ifo_dir {
 	return sprintf ("%s/ifo", $self->snap_dir);
 }
 
+sub set_name {
+	my $self = shift;
+	my ($new_name) = @_;
+	
+	my $old_name = $self->name;
+
+	my $project_dir = $self->config('base_project_dir');
+	
+	if ( $self->vob_dir eq "$project_dir/$old_name/vob" ) {
+		$self->set_vob_dir("$project_dir/$new_name/vob");
+	}
+	     
+	if ( $self->avi_dir eq "$project_dir/$old_name/avi" ) {
+		$self->set_avi_dir("$project_dir/$new_name/avi");
+	}
+
+	if ( $self->snap_dir eq "$project_dir/$old_name/tmp" ) {
+		$self->set_snap_dir("$project_dir/$new_name/tmp");
+	}
+	
+	$self->{name} = $new_name;
+	
+	1;
+}
+
 sub new {
 	my $class = shift;
-	my %par = @_;
-	my  ($name, $filename) =
-	@par{'name','filename'};
-	
-	confess "missing name" if not $name;
-	
-	my $self = {
-		name              => $name,
-		version           => $Video::DVDRip::VERSION,
-		filename          => $filename,
-		dvd_device	  => "/dev/dvd",
+
+	my $base_project_dir = $class->config('base_project_dir');
+
+	my $self = bless {
+		name              => "unnamed",
+		filename          => "unnamed.rip",
+		dvd_device	  => $class->config('dvd_device'),
 		rip_mode          => "rip",
-		vob_dir		  => undef,
-		avi_dir		  => undef,
-		snap_dir	  => undef,
+		vob_dir		  => "$base_project_dir/unnamed/vob",
+		avi_dir		  => "$base_project_dir/unnamed/avi",
+		snap_dir	  => "$base_project_dir/unnamed/tmp",
 		content  	  => undef,
 		last_saved_data   => undef,
 		selected_title_nr => undef,
-	};
-	
-	bless $self, $class;
+		version           => $Video::DVDRip::VERSION,
+	}, $class;
 
 	my $content = Video::DVDRip::Content->new ( project => $self );
 
@@ -132,7 +151,7 @@ sub save {
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or confess "can't write $filename";
-	print $fh q{# $Id: Project.pm,v 1.44 2004/10/10 12:48:05 joern Exp $},"\n";
+	print $fh q{# $Id: Project.pm,v 1.45 2005/07/23 08:14:15 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
@@ -142,6 +161,12 @@ sub save {
 
 	$self->log (__x("Project file saved to '{filename}'", filename => $filename));
 
+	my $dir = $self->snap_dir;
+	if ( ! -d $dir ) {
+		mkpath([$dir], 0, 0755) or die "can't create directory $dir";
+		$self->log (__x("Project temporary dir '{dir}' created", dir => $dir));
+	}
+
 	1;
 }
 
